summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-11-16 19:43:43 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-11-16 20:04:08 -0600
commit52a25e7c432515b9e48c6802e40f2534bd9be077 (patch)
tree2c0e953bc6754c89df22488d9f1f6d5cf5c66da1
parent25fd90f882f27d31e0caa34752b9648f1842a058 (diff)
downloadlibpng-52a25e7c432515b9e48c6802e40f2534bd9be077.tar.gz
[libpng14] Imported from libpng-1.4.14rc02.tarv1.4.14rc02
-rw-r--r--CMakeLists.txt2
-rw-r--r--INSTALL4
-rw-r--r--LICENSE4
-rw-r--r--Makefile.am2
-rw-r--r--Makefile.in2
-rw-r--r--README12
-rwxr-xr-xconfigure22
-rw-r--r--configure.ac4
-rw-r--r--libpng-1.4.14rc02.txt (renamed from libpng-1.4.14rc01.txt)10
-rw-r--r--libpng.322
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h20
-rw-r--r--pngconf.h2
-rw-r--r--pngpriv.h2
-rw-r--r--pngread.c2
-rw-r--r--pngtest.c2
-rw-r--r--pngwrite.c4
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt12
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/png32ce.def2
-rw-r--r--scripts/pngos2.def2
-rw-r--r--scripts/pngwin.def2
30 files changed, 80 insertions, 80 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 5deec073c..9b602cfc8 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -255,7 +255,7 @@ install(CODE ${PNG_CONFIG_INSTALL_CODE})
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 14.${PNGLIB_RELEASE}.1.4.14rc01
+# VERSION 14.${PNGLIB_RELEASE}.1.4.14rc02
VERSION 14.${PNGLIB_RELEASE}.0
SOVERSION 14
CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index 6b91deb6e..c6f9f4eed 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
-Installing libpng version 1.4.14rc01 - November 13, 2014
+Installing libpng version 1.4.14rc02 - November 17, 2014
On Unix/Linux and similar systems, you can simply type
@@ -46,7 +46,7 @@ to have access to the zlib.h and zconf.h include files that
correspond to the version of zlib that's installed.
You can rename the directories that you downloaded (they
-might be called "libpng-1.4.14rc01" or "libpng14" and "zlib-1.2.3"
+might be called "libpng-1.4.14rc02" or "libpng14" and "zlib-1.2.3"
or "zlib123") so that you have directories called "zlib" and "libpng".
Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index a331dc09e..057929cfd 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.4.14rc01, November 13, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.14rc02, November 17, 2014, are
Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-November 13, 2014
+November 17, 2014
diff --git a/Makefile.am b/Makefile.am
index 002d53ad2..4ae3e4fac 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -79,7 +79,7 @@ EXTRA_DIST= \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.14rc01.txt
+ example.c libpng-1.4.14rc02.txt
CLEANFILES= pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
diff --git a/Makefile.in b/Makefile.in
index 792cb83bd..c34581a35 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -616,7 +616,7 @@ EXTRA_DIST = \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.14rc01.txt
+ example.c libpng-1.4.14rc02.txt
CLEANFILES = pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
diff --git a/README b/README
index db3924492..2a6aa4be5 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.4.14rc01 - November 13, 2014 (shared library 14.0)
+README for libpng version 1.4.14rc02 - November 17, 2014 (shared library 14.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
@@ -187,9 +187,9 @@ Files in this distribution:
makefile.std => Generic UNIX makefile (cc, creates static
libpng.a)
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng14.so.14.1.4.14rc01)
+ (gcc, creates libpng14.so.14.1.4.14rc02)
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.14rc01)
+ (gcc, creates libpng14.so.14.1.4.14rc02)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -211,12 +211,12 @@ Files in this distribution:
makefile.openbsd => OpenBSD makefile
makefile.sgi => Silicon Graphics IRIX (cc, creates static lib)
makefile.sggcc => Silicon Graphics
- (gcc, creates libpng14.so.14.1.4.14rc01)
+ (gcc, creates libpng14.so.14.1.4.14rc02)
makefile.sunos => Sun makefile
makefile.solaris => Solaris 2.X makefile
- (gcc, creates libpng14.so.14.1.4.14rc01)
+ (gcc, creates libpng14.so.14.1.4.14rc02)
makefile.so9 => Solaris 9 makefile
- (gcc, creates libpng14.so.14.1.4.14rc01)
+ (gcc, creates libpng14.so.14.1.4.14rc02)
makefile.32sunu => Sun Ultra 32-bit makefile
makefile.64sunu => Sun Ultra 64-bit makefile
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
diff --git a/configure b/configure
index 4fe7861b5..cc033370e 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for libpng 1.4.14rc01.
+# Generated by GNU Autoconf 2.69 for libpng 1.4.14rc02.
#
# Report bugs to <png-mng-implement@lists.sourceforge.net>.
#
@@ -590,8 +590,8 @@ MAKEFLAGS=
# Identity of this package.
PACKAGE_NAME='libpng'
PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.4.14rc01'
-PACKAGE_STRING='libpng 1.4.14rc01'
+PACKAGE_VERSION='1.4.14rc02'
+PACKAGE_STRING='libpng 1.4.14rc02'
PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
PACKAGE_URL=''
@@ -1330,7 +1330,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures libpng 1.4.14rc01 to adapt to many kinds of systems.
+\`configure' configures libpng 1.4.14rc02 to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1400,7 +1400,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of libpng 1.4.14rc01:";;
+ short | recursive ) echo "Configuration of libpng 1.4.14rc02:";;
esac
cat <<\_ACEOF
@@ -1512,7 +1512,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-libpng configure 1.4.14rc01
+libpng configure 1.4.14rc02
generated by GNU Autoconf 2.69
Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1935,7 +1935,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by libpng $as_me 1.4.14rc01, which was
+It was created by libpng $as_me 1.4.14rc02, which was
generated by GNU Autoconf 2.69. Invocation command line was
$ $0 $@
@@ -2798,7 +2798,7 @@ fi
# Define the identity of the package.
PACKAGE='libpng'
- VERSION='1.4.14rc01'
+ VERSION='1.4.14rc02'
cat >>confdefs.h <<_ACEOF
@@ -2914,7 +2914,7 @@ fi
-PNGLIB_VERSION=1.4.14rc01
+PNGLIB_VERSION=1.4.14rc02
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
PNGLIB_RELEASE=14
@@ -13119,7 +13119,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by libpng $as_me 1.4.14rc01, which was
+This file was extended by libpng $as_me 1.4.14rc02, which was
generated by GNU Autoconf 2.69. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -13185,7 +13185,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-libpng config.status 1.4.14rc01
+libpng config.status 1.4.14rc02
configured by $0, generated by GNU Autoconf 2.69,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index 97a3c5062..e54de944b 100644
--- a/configure.ac
+++ b/configure.ac
@@ -16,14 +16,14 @@ dnl should not be necessary to regenerate configure if the time
dnl stamps are correct
AC_PREREQ(2.59)
-AC_INIT([libpng], [1.4.14rc01], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.4.14rc02], [png-mng-implement@lists.sourceforge.net])
AM_INIT_AUTOMAKE
dnl stop configure from automagically running automake
AM_MAINTAINER_MODE
dnl Version number stuff here:
-PNGLIB_VERSION=1.4.14rc01
+PNGLIB_VERSION=1.4.14rc02
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
PNGLIB_RELEASE=14
diff --git a/libpng-1.4.14rc01.txt b/libpng-1.4.14rc02.txt
index ca24a5e51..e54b01371 100644
--- a/libpng-1.4.14rc01.txt
+++ b/libpng-1.4.14rc02.txt
@@ -1,6 +1,6 @@
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.14rc01 - November 13, 2014
+ libpng version 1.4.14rc02 - November 17, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.14rc01 - November 13, 2014
+ libpng versions 0.97, January 1998, through 1.4.14rc02 - November 17, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -906,7 +906,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.14rc01, not all possible expansions are supported.
+As of libpng version 1.4.14rc02, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -3316,13 +3316,13 @@ Other rules can be inferred by inspecting the libpng source.
XIII. Y2K Compliance in libpng
-November 13, 2014
+November 17, 2014
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.14rc01 are Y2K compliant. It is my belief that earlier
+upward through 1.4.14rc02 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index 300839219..b638b690b 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "November 13, 2014"
+.TH LIBPNG 3 "November 17, 2014"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.14rc01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.14rc02
.SH SYNOPSIS
\fB
#include <png.h>\fP
@@ -442,7 +442,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.14rc01 - November 13, 2014
+ libpng version 1.4.14rc02 - November 17, 2014
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -453,7 +453,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.14rc01 - November 13, 2014
+ libpng versions 0.97, January 1998, through 1.4.14rc02 - November 17, 2014
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -1348,7 +1348,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.14rc01, not all possible expansions are supported.
+As of libpng version 1.4.14rc02, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -3758,13 +3758,13 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIII. Y2K Compliance in libpng
-November 13, 2014
+November 17, 2014
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.14rc01 are Y2K compliant. It is my belief that earlier
+upward through 1.4.14rc02 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
@@ -3977,7 +3977,7 @@ the first widely used release:
1.4.13rc01-02 14 10413 14.so.14.13[.0]
1.4.13 14 10413 14.so.14.13[.0]
1.4.14beta01 14 10414 14.so.14.14[.0]
- 1.4.14rc01 14 10414 14.so.14.14[.0]
+ 1.4.14rc01-02 14 10414 14.so.14.14[.0]
Henceforth the source version will match the shared-library minor
and patch numbers; the shared-library major version number will be
@@ -4033,7 +4033,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.4.14rc01 - November 13, 2014:
+Libpng version 1.4.14rc02 - November 17, 2014:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -4056,7 +4056,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.4.14rc01, November 13, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.14rc02, November 17, 2014, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -4155,7 +4155,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-November 13, 2014
+November 17, 2014
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 806666f07..0cf7ea433 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "November 13, 2014"
+.TH LIBPNGPF 3 "November 17, 2014"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.14rc01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.14rc02
(private functions)
.SH SYNOPSIS
\fB#include <png.h>
diff --git a/png.5 b/png.5
index 50bd5804a..026737936 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "November 13, 2014"
+.TH PNG 5 "November 17, 2014"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 7463f7cc3..df8346077 100644
--- a/png.c
+++ b/png.c
@@ -17,7 +17,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_14rc01 Your_png_h_is_not_version_1_4_14rc01;
+typedef version_1_4_14rc02 Your_png_h_is_not_version_1_4_14rc02;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -547,13 +547,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
#ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version 1.4.14rc01 - November 13, 2014" PNG_STRING_NEWLINE \
+ "libpng version 1.4.14rc02 - November 17, 2014" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
#else
- return ((png_charp) "libpng version 1.4.14rc01 - November 13, 2014\
+ return ((png_charp) "libpng version 1.4.14rc02 - November 17, 2014\
Copyright (c) 1998-2010 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
diff --git a/pngconf.h b/pngconf.h
index 61a599c73..3a01edf60 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.4.14rc01 - November 13, 2014
+ * libpng version 1.4.14rc02 - November 17, 2014
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpriv.h b/pngpriv.h
index 92bb89192..2c1b80ca5 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
/* pngpriv.h - private declarations for use inside libpng
*
- * libpng version 1.4.14rc01 - November 13, 2014
+ * libpng version 1.4.14rc02 - November 17, 2014
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngread.c b/pngread.c
index c854db541..c10b465db 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
/* pngread.c - read a PNG file
*
- * Last changed in libpng 1.4.13 [February 6, 2014]
+ * Last changed in libpng 1.4.14 [November 20, 2014]
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngtest.c b/pngtest.c
index a27d25fda..818a0e38a 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1702,4 +1702,4 @@ main(int argc, char *argv[])
}
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_14rc01 your_png_h_is_not_version_1_4_14rc01;
+typedef version_1_4_14rc02 your_png_h_is_not_version_1_4_14rc02;
diff --git a/pngwrite.c b/pngwrite.c
index c2533d43f..26a8f56d4 100644
--- a/pngwrite.c
+++ b/pngwrite.c
@@ -1,8 +1,8 @@
/* pngwrite.c - general routines to write a PNG file
*
- * Last changed in libpng 1.4.8 [July 7, 2011]
- * Copyright (c) 1998-2011 Glenn Randers-Pehrson
+ * Last changed in libpng 1.4.14 [November 20, 2014]
+ * Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index f87be51e4..b8b59ed47 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.4.14rc01 - November 13, 2014
+libpng version 1.4.14rc02 - November 17, 2014
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index b068a4353..1b422bd55 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source and build
*
- * libpng version 1.4.14rc01 - November 13, 2014
+ * libpng version 1.4.14rc02 - November 17, 2014
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 876476d54..200cfd32c 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,8 +1,8 @@
-Makefiles for libpng version 1.4.14rc01 - November 13, 2014
+Makefiles for libpng version 1.4.14rc02 - November 17, 2014
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.14rc01)
+ (gcc, creates libpng14.so.14.1.4.14rc02)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@ Makefiles for libpng version 1.4.14rc01 - November 13, 2014
makefile.dec => DEC Alpha UNIX makefile
makefile.dj2 => DJGPP 2 makefile
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng14.so.14.1.4.14rc01)
+ (gcc, creates libpng14.so.14.1.4.14rc02)
makefile.freebsd => FreeBSD makefile
makefile.gcc => Generic gcc makefile
makefile.hpgcc => HPUX makefile using gcc
@@ -36,12 +36,12 @@ Makefiles for libpng version 1.4.14rc01 - November 13, 2014
makefile.os2 => OS/2 Makefile (gcc and emx, requires pngos2.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng14.so.14.1.4.14rc01)
+ creates libpng14.so.14.1.4.14rc02)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng14.so.14.1.4.14rc01)
+ creates libpng14.so.14.1.4.14rc02)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng14.so.14.1.4.14rc01)
+ creates libpng14.so.14.1.4.14rc02)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 58c9eca10..6bc872317 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.4.14rc01
+version=1.4.14rc02
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 4f22d69a5..068e370f9 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng14
Name: libpng
Description: Loads and saves PNG files
-Version: 1.4.14rc01
+Version: 1.4.14rc02
Libs: -L${libdir} -lpng14
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 572663edb..9d6320087 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng14
LIB= png14
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.14rc01
+SHLIB_MINOR= 1.4.14rc02
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 5f4d11c10..42ca19abb 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 3
-SHLIB_MINOR= 1.4.14rc01
+SHLIB_MINOR= 1.4.14rc02
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 3e46ecbe5..9dd86f3ca 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.14rc01
+SHLIB_MINOR= 1.4.14rc02
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/png32ce.def b/scripts/png32ce.def
index 61a9094d8..5f6b747a8 100644
--- a/scripts/png32ce.def
+++ b/scripts/png32ce.def
@@ -15,7 +15,7 @@ LIBRARY lpngce
png_get_int_32
EXPORTS
-;Version 1.4.14rc01
+;Version 1.4.14rc02
png_build_grayscale_palette @1
; png_check_sig @2
png_chunk_error @3
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index 550ce8225..f696d2e3f 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
; PNG.LIB module definition file for OS/2
;----------------------------------------
-; Version 1.4.14rc01
+; Version 1.4.14rc02
LIBRARY PNG
DESCRIPTION "PNG image compression library for OS/2"
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index 9e8be69b9..09b5a7229 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -5,7 +5,7 @@
LIBRARY
EXPORTS
-;Version 1.4.14rc01
+;Version 1.4.14rc02
png_build_grayscale_palette
png_chunk_error
png_chunk_warning
diff --git a/png.h b/png.h
index 2efe5763f..09da2b61b 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.4.14rc01 - November 13, 2014
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.4.14rc01 - November 13, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -174,7 +174,7 @@
* 1.4.13rc01-02 14 10413 14.so.14.13[.0]
* 1.4.13 14 10413 14.so.14.13[.0]
* 1.4.14beta01 14 10414 14.so.14.14[.0]
- * 1.4.14rc01 14 10414 14.so.14.14[.0]
+ * 1.4.14rc01-02 14 10414 14.so.14.14[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -206,7 +206,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.4.14rc01, November 13, 2014, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -318,13 +318,13 @@
* Y2K compliance in libpng:
* =========================
*
- * November 13, 2014
+ * November 17, 2014
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.4.14rc01 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -380,9 +380,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.14rc01"
+#define PNG_LIBPNG_VER_STRING "1.4.14rc02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.4.14rc01 - November 13, 2014\n"
+ " libpng version 1.4.14rc02 - November 17, 2014\n"
#define PNG_LIBPNG_VER_SONUM 14
#define PNG_LIBPNG_VER_DLLNUM 14
@@ -395,7 +395,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1506,7 +1506,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_4_14rc01;
+typedef png_structp version_1_4_14rc02;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.4.14rc01 - November 13, 2014
+ * libpng version 1.4.14rc02 - November 17, 2014
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.4.14rc01 - November 13, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.4.14rc02 - November 17, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -206,7 +206,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.4.14rc01, November 13, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.14rc02, November 17, 2014, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -318,13 +318,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.4.14rc01 are Y2K compliant. It is my belief that earlier
+ * upward through 1.4.14rc02 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*